{% extends "tcms_base.html" %} {% load static %} {% block subtitle %}Plan History{% endblock %} {% block custom_stylesheet %} {% endblock %} {% block custom_javascript %}
{% endblock %} {% block content_type %} {% endblock %} {% block contents %}
Home >> Planning >> {{ testplan.plan_id }}: {{ testplan.name }} >> Edit History

## {{ testplan.name }}

Text Version | Modified Date | Changed By | Document Preview
--- | --- | --- | ---
{% for plan_text in test_plan_texts %}
{{ plan_text.plan_text_version }} | {{ plan_text.create_date }} | {{ plan_text.author.email }} | {{ plan_text.plan_text|striptags|truncatewords:"10" }}
{% if plan_text.plan_text_version == select_plan_text_version %}
| {{ plan_text.plan_text|safe }}
{% endif %} {% endfor %}

{% endblock %}